1.0 - Initial release

## v1.1.0 - 2023-06-13

v1.1.0

- Minimal unit test
- Code formatting
- Continuous integration

<!-- Release notes generated using configuration in .github/release.yml at main -->
### What's Changed

#### Other Changes

- Special subset logic by @jfoster17 in https://github.com/gluesolutions/glue-heatmap/pull/1
- Add extract_to_matrix menubar plugin by @jfoster17 in https://github.com/gluesolutions/glue-heatmap/pull/2
- Make cluster tool not a toggle but allow click and click again to unc… by @jfoster17 in https://github.com/gluesolutions/glue-heatmap/pull/3

### New Contributors

- @jfoster17 made their first contribution in https://github.com/gluesolutions/glue-heatmap/pull/1

**Full Changelog**: https://github.com/gluesolutions/glue-heatmap/commits/v1.1.0
